Class: Rack::Lint::ErrorWrapper
- Inherits:
-
Object
- Object
- Rack::Lint::ErrorWrapper
- Includes:
- Assertion
- Defined in:
- lib/rack/lint.rb
Instance Method Summary collapse
-
#close(*args) ⇒ Object
-
closemust never be called on the error stream.
-
-
#flush ⇒ Object
-
flushmust be called without arguments and must be called in order to make the error appear for sure.
-
-
#initialize(error) ⇒ ErrorWrapper
constructor
A new instance of ErrorWrapper.
-
#puts(str) ⇒ Object
-
putsmust be called with a single argument that responds toto_s.
-
-
#write(str) ⇒ Object
-
writemust be called with a single argument that is a String.
-
Methods included from Assertion
Constructor Details
#initialize(error) ⇒ ErrorWrapper
Returns a new instance of ErrorWrapper.
282 283 284 |
# File 'lib/rack/lint.rb', line 282 def initialize(error) @error = error end |
Instance Method Details
#close(*args) ⇒ Object
-
closemust never be called on the error stream.
304 305 306 |
# File 'lib/rack/lint.rb', line 304 def close(*args) assert("rack.errors#close must not be called") { false } end |
#flush ⇒ Object
-
flushmust be called without arguments and must be called in order to make the error appear for sure.
299 300 301 |
# File 'lib/rack/lint.rb', line 299 def flush @error.flush end |
#puts(str) ⇒ Object
-
putsmust be called with a single argument that responds toto_s.
287 288 289 |
# File 'lib/rack/lint.rb', line 287 def puts(str) @error.puts str end |
#write(str) ⇒ Object
-
writemust be called with a single argument that is a String.
292 293 294 295 |
# File 'lib/rack/lint.rb', line 292 def write(str) assert("rack.errors#write not called with a String") { str.instance_of? String } @error.write str end |